Module analyze

Module analyze 

Modules

feature_flags
Feature flag collection and cross-reference with dead code findings.

Functions

find_dead_code_fullDeprecated
Find all dead code, with optional resolved module data, plugin context, and workspace info.
rules_applying_to_path
Return rule-pack rules whose file and zone scope applies to a path.