Module cache

Module cache 

Re-exports from fallow-extract::cache.

The cache module has been moved to the fallow-extract crate since it is tightly coupled with the parsing/extraction pipeline. This module provides backwards-compatible re-exports so that fallow_core::cache::* paths continue to resolve.

Structs

CacheStore
Cached module information stored on disk.
CachedDynamicImport
Cached dynamic import data.
CachedDynamicImportPattern
Cached dynamic import pattern data (template literals, import.meta.glob).
CachedExport
Cached export data for a single export declaration.
CachedImport
Cached import data for a single import declaration.
CachedMember
Cached enum or class member data.
CachedModule
Cached data for a single module.
CachedReExport
Cached re-export data.
CachedRequireCall
Cached require() call data.
CachedSuppression
Cached suppression directive.

Functions

cached_to_module
Reconstruct a ModuleInfo from a CachedModule.
module_to_cached
Convert a ModuleInfo to a CachedModule for storage.