Structs
- Hashed
Token - A token with a precomputed hash for use in the detection engine.
Functions
- normalize_
and_ hash - Normalize and hash a token sequence according to the detection mode.
- normalize_
and_ hash_ resolved - Normalize and hash with explicit resolved normalization flags.