pub fn parse_single_file(file: &DiscoveredFile) -> Option<ModuleInfo>Expand description
Parse a single file and extract module information (without complexity).
pub fn parse_single_file(file: &DiscoveredFile) -> Option<ModuleInfo>Parse a single file and extract module information (without complexity).