pub struct SourceRegion {
pub body: String,
pub byte_offset: usize,
}Expand description
A source region extracted from a larger file while preserving the byte offset of the region body in the original source.
Fields
body: StringRegion body text.
byte_offset: usizeByte offset of body within the original source.