pub struct DirectImporterSummary {
pub source: FileId,
pub symbols: Vec<ImportedSymbolSummary>,
}Expand description
Importer details for one file that directly imports a target module.
Fields
source: FileIdSource file that imports the requested target.
symbols: Vec<ImportedSymbolSummary>Symbols imported from the target by this source file.