pub struct GraphCacheManifest {
pub version: u32,
pub mode: GraphCacheMode,
pub files: Vec<GraphCacheFile>,
}Expand description
Manifest inputs required to trust a persisted graph cache entry.
Fields
version: u32Schema version used by the persisted graph-cache entry.
mode: GraphCacheModeGraph-affecting option dimensions.
files: Vec<GraphCacheFile>Stable file identities, current FileId assignments, and freshness metadata.
Implementations
Sourceimpl GraphCacheManifest
impl GraphCacheManifest
Sourcepub fn new(
mode: GraphCacheMode,
files: Vec<GraphCacheFile>,
) -> GraphCacheManifest
pub fn new( mode: GraphCacheMode, files: Vec<GraphCacheFile>, ) -> GraphCacheManifest
Build a manifest and sort files by stable key for deterministic compare.
Sourcepub fn from_discovered_files(
root: &Path,
files: &[DiscoveredFile],
mode: GraphCacheMode,
fingerprint_for_path: impl FnMut(&Path) -> SourceFingerprint,
) -> GraphCacheManifest
pub fn from_discovered_files( root: &Path, files: &[DiscoveredFile], mode: GraphCacheMode, fingerprint_for_path: impl FnMut(&Path) -> SourceFingerprint, ) -> GraphCacheManifest
Build a manifest from discovered files plus a fingerprint provider.
Sourcepub fn matches_inputs(&self, current: &GraphCacheManifest) -> bool
pub fn matches_inputs(&self, current: &GraphCacheManifest) -> bool
True when a persisted manifest matches the current graph inputs.
Sourcepub fn matches_resolution_inputs(&self, current: &GraphCacheManifest) -> bool
pub fn matches_resolution_inputs(&self, current: &GraphCacheManifest) -> bool
True when a persisted resolver payload can be remapped to current FileIds.
Unlike Self::matches_inputs, this intentionally ignores each row’s
file_id. It is not sufficient to trust the persisted ModuleGraph, but
it is sufficient to reuse stable-keyed resolver output and rebuild the
graph with current FileIds.