Module project
fallow_
core
3.31.0
Module project
Module Items
Structs
In crate fallow_
core
fallow_core
Module
project
Centralized project state with file registry and workspace metadata.
Structs

Project
State
Discovered files and workspace packages for one analysis run.