pub struct ProjectState { /* private fields */ }Expand description
Discovered files and workspace packages for one analysis run.
The files are indexed by their dense FileId.
Implementations
Sourceimpl ProjectState
impl ProjectState
Sourcepub fn new(
files: Vec<DiscoveredFile>,
workspaces: Vec<WorkspaceInfo>,
) -> ProjectState
pub fn new( files: Vec<DiscoveredFile>, workspaces: Vec<WorkspaceInfo>, ) -> ProjectState
Build a new project state from discovered files and workspaces.
Sourcepub fn files(&self) -> &[DiscoveredFile]
pub fn files(&self) -> &[DiscoveredFile]
All discovered files, indexed by FileId.
Sourcepub fn workspaces(&self) -> &[WorkspaceInfo]
pub fn workspaces(&self) -> &[WorkspaceInfo]
All discovered workspace packages.
Sourcepub fn file_by_id(&self, id: FileId) -> Option<&DiscoveredFile>
pub fn file_by_id(&self, id: FileId) -> Option<&DiscoveredFile>
Look up a file by its FileId.