pub fn parse_script(script: &str) -> Vec<ScriptCommand>Expand description
Parse a single script value into one or more commands.
Splits on shell operators (&&, ||, ;, |, &) and parses each segment.
pub fn parse_script(script: &str) -> Vec<ScriptCommand>Parse a single script value into one or more commands.
Splits on shell operators (&&, ||, ;, |, &) and parses each segment.