pub struct PipelineTimings {Show 17 fields
pub discover_files_ms: f64,
pub file_count: usize,
pub workspaces_ms: f64,
pub workspace_count: usize,
pub plugins_ms: f64,
pub script_analysis_ms: f64,
pub parse_extract_ms: f64,
pub module_count: usize,
pub cache_hits: usize,
pub cache_misses: usize,
pub cache_update_ms: f64,
pub entry_points_ms: f64,
pub entry_point_count: usize,
pub resolve_imports_ms: f64,
pub build_graph_ms: f64,
pub analyze_ms: f64,
pub total_ms: f64,
}Expand description
Pipeline performance timings.
Fields
discover_files_ms: f64file_count: usizeworkspaces_ms: f64workspace_count: usizeplugins_ms: f64script_analysis_ms: f64parse_extract_ms: f64module_count: usizecache_hits: usizeNumber of files whose parse results were loaded from cache (skipped parsing).
cache_misses: usizeNumber of files that required a full parse (new or changed content).
cache_update_ms: f64entry_points_ms: f64entry_point_count: usizeresolve_imports_ms: f64build_graph_ms: f64analyze_ms: f64total_ms: f64Trait Implementations
Sourceimpl Clone for PipelineTimings
impl Clone for PipelineTimings
Sourcefn clone(&self) -> PipelineTimings
fn clone(&self) -> PipelineTimings
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PipelineTimings
impl Debug for PipelineTimings