Modules
- feature_
flags - Feature flag collection and cross-reference with dead code findings.
Functions
- find_
dead_ code_ full Deprecated - Find all dead code, with optional resolved module data, plugin context, and workspace info.
- rules_
applying_ to_ path - Return rule-pack rules whose file and zone scope applies to a path.