Module analyze

Module analyze 

Functions

find_dead_code
Find all dead code in the project.
find_dead_code_full
Find all dead code, with optional resolved module data, plugin context, and workspace info.
find_dead_code_with_resolved
Find all dead code, with optional resolved module data and plugin context.