Module normalize

Module normalize 

Structs

HashedToken
A token with a precomputed hash for use in the detection engine.

Functions

normalize_and_hash
Normalize and hash a token sequence according to the detection mode.
normalize_and_hash_resolved
Normalize and hash with explicit resolved normalization flags.