Module tokenize

Module tokenize 

Re-exports

pub use super::token_types::FileTokens;
pub use super::token_types::KeywordType;
pub use super::token_types::OperatorType;
pub use super::token_types::PunctuationType;
pub use super::token_types::SourceToken;
pub use super::token_types::TokenKind;

Functions

tokenize_file
Tokenize a source file into a sequence of normalized tokens.
tokenize_file_cross_language
Tokenize a source file with optional type stripping for cross-language detection.