Structs
- File
Tokens - Result of tokenizing a source file.
- Source
Token - A single token extracted from the AST with its source location.
Enums
- Keyword
Type - JavaScript/TypeScript keyword types.
- Operator
Type - Operator categories.
- Punctuation
Type - Punctuation / delimiter types.
- Token
Kind - Normalized token types for clone detection.
Functions
- tokenize_
file - Tokenize a source file into a sequence of normalized tokens.
- tokenize_
file_ cross_ language - Tokenize a source file with optional type stripping for cross-language detection.