Structs
- Dynamic
Import Info - A dynamic
import()call. - Dynamic
Import Pattern - A dynamic import with a pattern that can be partially resolved (e.g., template literals).
- Export
Info - An export declaration.
- Import
Info - An import declaration.
- Member
Access - A static member access expression (e.g.,
Status.Active,MyClass.create()). - Member
Info - A member of an enum or class.
- Module
Info - Extracted module information from a single file.
- ReExport
Info - A re-export declaration.
- Require
Call Info - A
require()call.
Enums
- Export
Name - Export identifier.
- Imported
Name - How a symbol is imported.
- Member
Kind - The kind of member.
Functions
- parse_
all_ files - Parse all files in parallel, extracting imports and exports. Uses the cache to skip reparsing files whose content hasn’t changed.
- parse_
from_ content - Parse from in-memory content (for LSP).
- parse_
single_ file - Parse a single file and extract module information.