Vue/Svelte Single File Component (SFC) script extraction.
Extracts <script> block content from .vue and .svelte files using regex,
handling lang, src, and generic attributes, and filtering HTML comments.
Structs
- SfcScript
- An extracted
<script>block from a Vue or Svelte SFC.
Functions
- extract_
sfc_ scripts - Extract all
<script>blocks from a Vue/Svelte SFC source string. - is_
sfc_ file - Check if a file path is a Vue or Svelte SFC (
.vueor.svelte).