pub fn config_for_project(
root: &Path,
config_path: Option<&Path>,
) -> Result<(ResolvedConfig, Option<PathBuf>), FallowError>Expand description
Resolve the analysis config for a project, mirroring the CLI’s --config
behavior when config_path is provided.
Errors
Returns an error when an explicit config cannot be loaded or automatic config discovery finds an invalid config.