Centralized project state with file registry and workspace metadata.
Structs
- Project
State - Centralized project state owning the file registry and workspace metadata.
Centralized project state with file registry and workspace metadata.