Module trace

Module trace 

Structs

CloneTrace
Result of tracing a clone: all groups containing the code at a source location or addressed by a stable clone fingerprint.
DependencyTrace
Result of tracing a dependency: where it is used.
ExportReference
A direct reference to an export.
ExportTrace
Result of tracing an export: why it is considered used or unused.
FileTrace
Result of tracing all edges for a file.
ImpactClosureGap
One coordination-gap entry in an ImpactClosureTrace.
ImpactClosureTrace
Result of computing the impact closure for a single file as the seed.
PipelineTimings
Pipeline performance timings.
ReExportChain
A re-export chain showing how an export is propagated.
TracedCloneGroup
One clone group returned from a clone trace request.
TracedExport
An export with usage information.
TracedReExport
A re-export with source information.

Functions

trace_clone
trace_clone_by_fingerprint
Trace a clone group by its stable content fingerprint.
trace_dependency
Trace where a dependency is used.
trace_export
Trace why an export is considered used or unused.
trace_file
Trace all edges for a file.
trace_impact_closure
Compute the impact closure for a single file as the seed.