Structs
- Clone
Trace - Result of tracing a clone: all groups containing the code at a source location or addressed by a stable clone fingerprint.
- Dependency
Trace - Result of tracing a dependency: where it is used.
- Export
Reference - A direct reference to an export.
- Export
Trace - Result of tracing an export: why it is considered used or unused.
- File
Trace - Result of tracing all edges for a file.
- Impact
Closure Gap - One coordination-gap entry in an
ImpactClosureTrace. - Impact
Closure Trace - Result of computing the impact closure for a single file as the seed.
- Pipeline
Timings - Pipeline performance timings.
- ReExport
Chain - A re-export chain showing how an export is propagated.
- Traced
Clone Group - One clone group returned from a clone trace request.
- Traced
Export - An export with usage information.
- Traced
ReExport - A re-export with source information.
Functions
- trace_
clone - trace_
clone_ by_ fingerprint - Trace a clone group by its stable content fingerprint.
- trace_
dependency - Trace where a dependency is used.
- trace_
export - Trace why an export is considered used or unused.
- trace_
file - Trace all edges for a file.
- trace_
impact_ closure - Compute the impact closure for a single file as the seed.