Module trace

Module trace 

Structs

CloneTrace
Result of tracing a clone: all groups containing the code at a given location.
DependencyTrace
Result of tracing a dependency: where is it used?
ExportReference
A direct reference to an export.
ExportTrace
Result of tracing an export: why is it considered used or unused?
FileTrace
Result of tracing all edges for a file.
PipelineTimings
Pipeline performance timings.
ReExportChain
A re-export chain showing how an export is propagated.
TracedCloneGroup
TracedExport
An export with its usage info.
TracedReExport
A re-export with source info.

Functions

trace_clone
trace_dependency
Trace where a dependency is used.
trace_export
Trace why an export is considered used or unused.
trace_file
Trace all edges for a file.